==> jei-1.21.1-fabric-19.25.0.325-sources.jar: mezz/jei/gui/overlay/bookmarks/history/LookupHistoryButton.java <==
package mezz.jei.gui.overlay.bookmarks.history;

import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.drawable.IDrawableStatic;
import mezz.jei.common.Internal;
import mezz.jei.common.config.IClientConfig;
import mezz.jei.common.gui.JeiTooltip;
import mezz.jei.common.gui.textures.Textures;
import mezz.jei.gui.elements.GuiIconToggleButton;
import mezz.jei.gui.input.UserInput;
import net.minecraft.class_124;
import net.minecraft.class_2561;

public class LookupHistoryButton extends GuiIconToggleButton {

	public static LookupHistoryButton create(IClientConfig clientConfig) {
		Textures textures = Internal.getTextures();
		IDrawableStatic offIcon = textures.getHistoryButtonDisabledIcon();
		IDrawableStatic onIcon = textures.getHistoryButtonEnabledICon();
		return new LookupHistoryButton(offIcon, onIcon, clientConfig);
	}

	private final IClientConfig clientConfig;

	private LookupHistoryButton(IDrawable offIcon, IDrawable onIcon, IClientConfig clientConfig) {
		super(offIcon, onIcon);
		this.clientConfig = clientConfig;
	}

	@Override
	protected void getTooltips(JeiTooltip tooltip) {
		if (clientConfig.isLookupHistoryEnabled()) {
			tooltip.add(class_2561.method_43471("jei.tooltip.lookupHistory.disable"));
		} else {
			tooltip.add(class_2561.method_43471("jei.tooltip.lookupHistory.enable"));
		}
		tooltip.add(
			class_2561.method_43471("jei.tooltip.lookupHistory.usage")
				.method_27692(class_124.field_1056)
				.method_27692(class_124.field_1080)
		);
	}

	@Override
	protected boolean isIconToggledOn() {
		return clientConfig.isLookupHistoryEnabled();
	}

	@Override
	protected boolean onMouseClicked(UserInput input) {
		if (!input.isSimulate()) {
			clientConfig.setLookupHistoryEnabled(!clientConfig.isLookupHistoryEnabled());
		}
		return true;
	}
}

==> jei-1.21.11-fabric-27.0.0.1-sources.jar: mezz/jei/gui/overlay/bookmarks/history/LookupHistoryButton.java <==
package mezz.jei.gui.overlay.bookmarks.history;

import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.drawable.IDrawableStatic;
import mezz.jei.common.Internal;
import mezz.jei.common.config.IClientConfig;
import mezz.jei.common.gui.JeiTooltip;
import mezz.jei.common.gui.textures.Textures;
import mezz.jei.gui.elements.GuiIconToggleButton;
import mezz.jei.gui.input.UserInput;
import net.minecraft.class_124;
import net.minecraft.class_2561;

public class LookupHistoryButton extends GuiIconToggleButton {

	public static LookupHistoryButton create(IClientConfig clientConfig) {
		Textures textures = Internal.getTextures();
		IDrawableStatic offIcon = textures.getHistoryButtonDisabledIcon();
		IDrawableStatic onIcon = textures.getHistoryButtonEnabledIcon();
		return new LookupHistoryButton(offIcon, onIcon, clientConfig);
	}

	private final IClientConfig clientConfig;

	private LookupHistoryButton(IDrawable offIcon, IDrawable onIcon, IClientConfig clientConfig) {
		super(offIcon, onIcon);
		this.clientConfig = clientConfig;
	}

	@Override
	protected void getTooltips(JeiTooltip tooltip) {
		if (clientConfig.isLookupHistoryEnabled()) {
			tooltip.add(class_2561.method_43471("jei.tooltip.lookupHistory.disable"));
		} else {
			tooltip.add(class_2561.method_43471("jei.tooltip.lookupHistory.enable"));
		}
		tooltip.add(
			class_2561.method_43471("jei.tooltip.lookupHistory.usage")
				.method_27692(class_124.field_1056)
				.method_27692(class_124.field_1080)
		);
	}

	@Override
	protected boolean isIconToggledOn() {
		return clientConfig.isLookupHistoryEnabled();
	}

	@Override
	protected boolean onMouseClicked(UserInput input) {
		if (!input.isSimulate()) {
			clientConfig.setLookupHistoryEnabled(!clientConfig.isLookupHistoryEnabled());
		}
		return true;
	}
}
